var group__PkgSearchStructuresRef =
[
    [ "Concepts", "group__PkgSearchStructuresConcepts.html", "group__PkgSearchStructuresConcepts" ],
    [ "Traits Classes", "group__PkgSearchStructuresTraitsClasses.html", "group__PkgSearchStructuresTraitsClasses" ],
    [ "Search Structures", "group__PkgSearchStructuresSearchStructure.html", "group__PkgSearchStructuresSearchStructure" ],
    [ "CGAL::Tree_anchor< Data, Window >", "classCGAL_1_1Tree__anchor.html", [
      [ "Data", "classCGAL_1_1Tree__anchor.html#a079b509cbff6b4c55297d4dcd4309f86", null ],
      [ "Window", "classCGAL_1_1Tree__anchor.html#a6d5361153adf222274953e856869881e", null ],
      [ "a", "classCGAL_1_1Tree__anchor.html#ae0f6a3d2946651e0ebecd11d67269a0f", null ],
      [ "enclosing_query", "classCGAL_1_1Tree__anchor.html#aedceb60a4645d4e839d6e6ff35c58b53", null ],
      [ "is_anchor", "classCGAL_1_1Tree__anchor.html#a0cda1dcf460ebb0a4c90469a3bb4e883", null ],
      [ "is_inside", "classCGAL_1_1Tree__anchor.html#a3b3bad65142baf0ebc835cdf438f4c80", null ],
      [ "is_valid", "classCGAL_1_1Tree__anchor.html#a370b3fd28f310e9a0d23a42786365066", null ],
      [ "window_query", "classCGAL_1_1Tree__anchor.html#a424445c61439c798468b70b117906f24", null ]
    ] ]
];